==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.contenttypes.calendar/src/com/openexchange/usm/contenttypes/calendar/impl/CalendarConstants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.calendar.impl;

public class CalendarConstants {

	public static final String CALENDAR_PATH = "calendar";

	public static final String NEW_APPOINTMENTS = "newappointments";

	//content type field names: Detailed appointment data

	public static final String COLOR_LABEL = "color_label";

	public static final String SHOWN_AS = "shown_as";

	public static final String FULL_TIME = "full_time";

	public static final String LOCATION = "location";

	public static final String RECURRENCE_ID = "recurrence_id";

	public static final String IGNORE_CONFLICTS = "ignore_conflicts";

	public static final String CONFLICTS = "conflicts";

	public static final String POS = "pos";

	//	public static final String RECURRENCE_MASTER = "recurrence_master";
	
	public static final String UID = "uid";

	public static final String ORGANIZER = "organizer";
	
	public static final String SEQUENCE = "sequence";
	
	public static final String CONFIRMATIONS = "confirmations";
	
	public static final String TIMEZONE = "timezone";
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.contenttypes.calendar/src/com/openexchange/usm/contenttypes/calendar/impl/CalendarConstants.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.contenttypes.calendar.impl;

public class CalendarConstants {

	public static final String CALENDAR_PATH = "calendar";

	public static final String NEW_APPOINTMENTS = "newappointments";

	//content type field names: Detailed appointment data

	public static final String COLOR_LABEL = "color_label";

	public static final String SHOWN_AS = "shown_as";

	public static final String FULL_TIME = "full_time";

	public static final String LOCATION = "location";

	public static final String RECURRENCE_ID = "recurrence_id";

	public static final String IGNORE_CONFLICTS = "ignore_conflicts";

	public static final String CONFLICTS = "conflicts";

	public static final String POS = "pos";

	//	public static final String RECURRENCE_MASTER = "recurrence_master";
	
	public static final String ORGANIZER = "organizer";
	
	public static final String SEQUENCE = "sequence";
	
	public static final String CONFIRMATIONS = "confirmations";
	
	public static final String TIMEZONE = "timezone";
	
	public static final String ORGANIZER_ID = "organizerId";
	
	public static final String PRINCIPAL = "principal";
	
	public static final String PRINCIPAL_ID = "principalId";
}
